@@ -12,19 +12,20 @@
 #'   \item Tfr (fraction)
 #' }
 #'
-#' @note Data downloaded from \url{http://midopt.com/filters/} on 2017-12-26.
-#' Republished with permission.
+#' @note Data downloaded from \url{http://midopt.com/filters/} on 2017-12-26 and
+#' 2019-05-10. Republished with permission.
 #' Copyright (c) Midwest Optical Systems, Inc. (MidOpt)
 #' \url{http://www.midopt.com/}
 #'
 #' @section DISCLAIMER from MidOpt: data are typical values and may vary by
-#' plus/minus 10 nm.
+#' plus/minus 10 nm. To interactively comparing filter spectra, please visit
+#' \url{https://midopt.com/tools/curve-compare/}.
 #'
 #' @docType data
 #' @keywords datasets
 #' @format A vector of character strings.
 #'
 #' @examples
-#' midopt
+#' midopt_filters
 #'
-"midopt"
+"midopt_filters"
